@@ -28,9 +28,9 @@ from .queue import PriorityQueue
 
 
 class JobQueue:
-    """"This object represents a bot job queue."""
+    """This object represents a bot job queue."""
 
-    def __init__(self, sender):
+    def __init__(self, sender) -> None:
         """Initialize job queue."""
         self._queue = PriorityQueue()
         self._sender = sender
